@@ -3,8 +3,11 @@ context("proj_predfun")
 test_that("repair_re() works for GLMMs", {
   # Setup -------------------------------------------------------------------
 
-  # Currently, version < 1.6-4 of package 'Matrix' is needed here:
-  skip_if(packageVersion("Matrix") >= "1.6-4")
+  # In the past, there have been incompatibility issues between packages
+  # 'Matrix' and 'lme4', see commits 2c6cbc5bc22a1779e9e5168a9459248fab1962c6
+  # and ba4ef23c4de6e13a9160e73e22aa4e01bf1b07ac and rstanarm issue
+  # stan-dev/rstanarm#610, so don't run this test on CRAN:
+  skip_on_cran()
 
   if (exists(".Random.seed", envir = .GlobalEnv)) {
     rng_old <- get(".Random.seed", envir = .GlobalEnv)
@@ -406,13 +409,6 @@ test_that(paste(
 ), {
   ### Fit with mclogit::mblogit() -------------------------------------------
 
-  warn_expected <- if (packageVersion("mclogit") <= "0.8.7.3") {
-    "variable 'prior' is absent, its contrast will be ignored"
-  } else if (packageVersion("mclogit") >= "0.9.6") {
-    "Inner iterations did not coverge"
-  } else {
-    NA
-  }
   expect_warning(
     out_capt <- capture.output(
       mfit <- mclogit::mblogit(
@@ -423,7 +419,7 @@ test_that(paste(
         y = FALSE
       )
     ),
-    warn_expected
+    NULL
   )
   expect_identical(tail(out_capt, 1), "converged")
 
@@ -634,7 +630,7 @@ test_that(paste(
                                  function(x) x[i, ])))
     }))
   dmnms <- list(NULL, dimnames(lpreds_man)[[2]])
-  expect_equal(lpreds, structure(lpreds_man, dimnames = dmnms),
+  expect_equal(as.numeric(lpreds), as.numeric(lpreds_man),
                tolerance = 1e-14)
 })
 
@@ -647,14 +643,6 @@ test_that(paste(
   skip_if_not(packageVersion("mclogit") >= "0.9")
 
   ### Fit with mclogit::mblogit() -------------------------------------------
-
-  warn_expected <- if (packageVersion("mclogit") <= "0.8.7.3") {
-    "variable 'prior' is absent, its contrast will be ignored"
-  } else if (packageVersion("mclogit") >= "0.9.6") {
-    "Inner iterations did not coverge"
-  } else {
-    NA
-  }
   expect_warning(
     out_capt <- capture.output(
       mfit <- mclogit::mblogit(
@@ -666,7 +654,6 @@ test_that(paste(
         y = FALSE
       )
     ),
-    warn_expected
   )
   expect_identical(tail(out_capt, 1), "converged")
 
@@ -920,7 +907,7 @@ test_that(paste(
                                  function(x) x[i, ])))
     }))
   dmnms <- list(NULL, dimnames(lpreds_man)[[2]])
-  expect_equal(lpreds, structure(lpreds_man, dimnames = dmnms),
+  expect_equal(as.numeric(lpreds), as.numeric(lpreds_man),
                tolerance = 1e-14)
 })
 
